"use client";

import Image from "next/image";

import { Icon } from "@iconify/react/dist/iconify.js";
import { ChevronRight, Inbox, MapPin, Phone } from "lucide-react";

import { Link, Locale } from "@/i18n/routing";

import { ImageBaseUrl } from "@/configs/api";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { useLocale } from "next-intl";
import { SmoothLink } from "../shared/smoth-link";
import CompaniesSection from "./companies/companies-section";

const footerData = {
	supportAndHelp: {
		title: {
			ar: "الدعم و المساعدة",
			en: "Support & Help",
		},
		links: [
			{
				title: {
					ar: "الأسئلة الشائعة",
					en: "FAQs",
				},
				href: "/about#faqs",
				isActive: true,
			},
			{
				title: {
					ar: "تواصل معنا",
					en: "Contact Us",
				},
				href: "/contact",
			},
		],
	},
	quickLinks: {
		title: {
			ar: "الروابط السريعة",
			en: "Quick Links",
		},
		links: [
			{
				title: {
					ar: "خدماتنا",
					en: "Our Services",
				},
				href: "/services",
			},
			{
				title: {
					ar: "مشاريعنا",
					en: "Our Projects",
				},
				href: "/projects",
			},
			{
				title: {
					ar: "منتجاتنا",
					en: "Our Products",
				},
				href: "/shop",
			},
			{
				title: {
					ar: "تاريخنا",
					en: "Our History",
				},
				href: "/about",
			},
			{
				title: {
					ar: "انضم لفريقنا",
					en: "Join Our Team",
				},
				href: "/request-for-employment",
			},
		],
	},
	stayConnected: {
		title: {
			ar: "إبق على تواصل",
			en: "Stay Connected",
		}
	}
};

export default function Footer() {
	const locale = useLocale() as Locale;
	const isRTL = locale === "ar";
	// const t = useTranslations("Common");

	const { texts } = useBasicInfo();

	return (
		<footer className="relative bg-[#606676] text-white">
			<div className="z-10 mx-auto max-w-7xl px-14 pt-12">
				<div className="flex flex-col items-stretch justify-between gap-12 md:flex-row">
					{/* Logo Section */}
					<div className="flex flex-[35%] flex-col gap-6">
						<Image
							src={ImageBaseUrl + texts?.footer_logo}
							alt="Bin Taleb Logo"
							width={100}
							height={100}
							priority
							className="mx-auto rounded-md bg-white p-2 lg:mx-0"
							style={{
								boxShadow: "0px 4px 4px 0px #00000040",
							}}
						/>
						{/* Description */}
						<p className="text-justify text-xs leading-6 text-custom-background-light">
							{texts?.footer_description?.[locale]}
						</p>

						{/* Contact Information */}
						<div className="flex flex-col gap-2">
							<div className="flex items-center gap-2">
								<MapPin
									size={30}
									className="h-8 w-8 shrink-0 rounded-lg bg-custom-primary-accent p-2 text-white"
								/>
								<span className="text-base text-custom-background-light">
									{texts?.address_footer?.[locale]}
								</span>
							</div>

							<div className="flex items-center gap-2">
								<Inbox
									size={30}
									className="h-8 w-8 shrink-0 rounded-lg bg-custom-primary-accent p-2 text-white"
								/>
								<span className="text-base text-custom-background-light">
									{texts?.footer_email}
								</span>
							</div>

							<div className="flex items-center gap-2">
								<Phone
									size={30}
									className="h-8 w-8 shrink-0 rounded-lg bg-custom-primary-accent p-2 text-white"
								/>
								<span className="text-base text-custom-background-light">
									{texts?.footer_phone}
								</span>
							</div>
						</div>
					</div>

					{/* Support & Help  */}
					<div className="flex-[20%] pt-12 text-custom-background-light">
						{/* Support & Help Title */}
						<p className="mb-5 text-[23px]">
							{footerData.supportAndHelp.title?.[locale]}
						</p>
						{/* Support Links */}
						<div className="flex flex-col gap-4">
							<div className="flex items-center gap-2">
								<Link
									href={"/contact" as any}
									className={"flex items-center gap-2 text-base text-[#B4BCD2]"}
								>
									<ChevronRight
										size={16}
										className={`text-white ${isRTL ? "rotate-180" : ""}`}
									/>
									{locale === "ar" ? "تواصل معنا" : "Contact Us"}
								</Link>
							</div>
							<div className="flex items-center gap-2">
								<SmoothLink
									href={"ar/about#faqs"}
									className={"flex items-center gap-2 text-base text-[#B4BCD2]"}
								>
									<ChevronRight
										size={16}
										className={`text-white ${isRTL ? "rotate-180" : ""}`}
									/>
									{locale === "ar" ? "الأسئلة الشائعة" : "FAQs"}
								</SmoothLink>
							</div>
						</div>
					</div>

					{/* Quick Links */}
					<div className="flex-[20%] pt-12 text-custom-background-light">
						{/* Quick Links Title */}
						<p className="mb-5 text-[23px]">
							{footerData.quickLinks.title?.[locale]}
						</p>
						{/* Quick Links */}
						<div className="flex flex-col gap-4">
							{footerData?.quickLinks?.links?.map((link, index) => (
								<div key={index}>
									<Link
										href={link.href as any}
										className={"flex items-center gap-2 text-base text-[#B4BCD2] hover:text-blue-400"}
									>
										<ChevronRight
											size={16}
											className={`text-white ${isRTL ? "rotate-180" : ""}`}
										/>
										{link.title?.[locale]}
									</Link>
								</div>
							))}
						</div>
					</div>

					{/* Stay Connected */}
					<div className="flex-[25%] pt-12 text-custom-background-light">
						{/* Stay Connected Title */}
						<p className="mb-5 text-[23px]">
							{footerData.stayConnected.title?.[locale]}
						</p>

						{/* Social Media Icons */}
						<div className="mt-8">
							<div className="flex justify-center gap-4">
								{[
									{ icon: "iconoir:whatsapp-solid", href: texts?.whatsapp_link ?? "/" },
									{ icon: "ri:youtube-fill", href: texts?.youtube_link ?? "/" },
									{ icon: "ri:instagram-line", href: texts?.instagram_link ?? "/" },
									{ icon: "prime:twitter", href: texts?.twitter_link ?? "/" },
									{ icon: "ri:facebook-fill", href: texts?.facebook_link ?? "/" },
								]?.map(({ icon, href }, index) => (
									<Link
										key={index}
										href={href as any}
										className="transform rounded-full bg-custom-background-light p-2 transition-all duration-200 hover:bg-custom-primary-accent"
										target="_blank"
										rel="noopener noreferrer"
									>
										<Icon
											icon={icon}
											width="16"
											height="16"
											className="text-custom-primary-accent hover:text-custom-background-light"
										/>
									</Link>
								))}
							</div>
						</div>
					</div>
				</div>
			</div>

			<Image
				src="/footer-ornament.png"
				alt="Footer Background"
				fill
				priority
				style={{ objectFit: "cover", pointerEvents: "none" }}
			/>
			<CompaniesSection />
			<div className="grid grid-cols-1 gap-8 lg:grid-cols-2">
				<div className="mx-auto flex items-center justify-center gap-8 text-center md:px-6 lg:px-8">
					<Link href={texts?.android_link ? texts.android_link : "/" as any}
						className="flex items-center w-32 h-12 gap-2 text-sm text-white bg-black rounded-lg p-2 border border-white sm:text-base"
					>

						<div style={{ lineHeight: "1.5" }}>
							<span className="text-[10px] float-left">Get it on</span>
							<div className="text-[12px]"> Google Play</div>
						</div>
						<Icon icon="logos:google-play-icon" className="h-6 w-6" />
					</Link>
					<Link href={texts?.iphone_link ? texts.iphone_link : "/" as any}
						className="flex items-center w-32 h-12 gap-1 text-sm text-white bg-black rounded-lg p-2 border border-white sm:text-base">
						<div style={{ lineHeight: "1.5" }}>
							<span className="text-[10px] float-left">Download on the</span>
							<div className="text-[12px]"> App Store</div>
						</div>
						<Icon icon="basil:apple-outline" className="h-7 w-7" />
					</Link>

				</div>
				<div className="mx-auto flex items-center justify-center gap-8 text-center md:px-6 lg:px-8">
					<Link
						href={"/"}
						className={"text-sm text-[#B4BCD2] hover:text-blue-400 sm:text-base"}
					>
						{locale === "ar" ? " شروط استخدام" : "Terms & Conditions"}
					</Link>
					<Link
						href={"/"}
						className={"text-sm text-[#B4BCD2] hover:text-blue-400 sm:text-base"}
					>
						{locale === "ar" ? "الخصوصية " : "Privacy Policy"}
					</Link>
				</div>
			</div>
			<div className="mt-8 bg-white py-4 text-center text-custom-dark-veryDark">
				<p className="text-base">
					{locale === "ar" ? (
						<>
							© 2024 <span className="text-[#2895C8]">بن طالب</span> جميع
							الحقوق محفوظة
						</>
					) : (
						<>
							© 2024 <span className="text-[#2895C8]">Bin Taleb</span> All
							rights reserved
						</>
					)}
				</p>
			</div>
		</footer>
	);
}
